@@ -14,7 +14,7 @@ from botocore.exceptions import ProfileNotFound
 from ego4d.cli.universities import UNIV_TO_BUCKET
 
 
-VERSION_DEFAULT = "v1"
+VERSION_DEFAULT = "v2_1"
 DATASET_PRIMARY = "full_scale"
 DATASETS_VIDEO = ["full_scale", "clips", "components/videos", "video_540ss"]
 DATASETS_FILE = [
@@ -28,9 +28,13 @@ DATASETS_FILE = [
     "av_models",
     "social_test",
     "vq2d_models",
+    "vq2d_detections",
     "sta_models",
     "lta_models",
     "slowfast8x8_r101_k400",
+    "egotracks",
+    "paco_annotations",
+    "paco_frames",
 ]
 DATASETS_ALL = DATASETS_VIDEO + DATASETS_FILE
 DATASET_FILE_EXTENSIONS = [
@@ -71,6 +75,11 @@ class ValidatedConfig(NamedTuple):
     list_datasets: bool
     manifest_override_path: str
 
+    @property
+    def out_version_dir(self) -> str:
+        base_version = self.version.split("_")[0]
+        return base_version
+
 
 class Config(NamedTuple):
     """
@@ -110,9 +119,9 @@ def validate_config(cfg: Config) -> ValidatedConfig:
         raise RuntimeError(f"Could not find AWS profile '{cfg.aws_profile_name}'.")
 
     return ValidatedConfig(
-        output_directory=Path(cfg.output_directory).expanduser()
-        if cfg.output_directory
-        else None,
+        output_directory=(
+            Path(cfg.output_directory).expanduser() if cfg.output_directory else None
+        ),
         version=cfg.version,
         datasets=set(cfg.datasets),
         benchmarks=set(cfg.benchmarks),
@@ -218,7 +227,7 @@ def config_from_args(args=None) -> Config:
     )
     flag_parser.add_argument(
         "--version",
-        help="A version identifier - i.e. 'v1'",
+        help="A version identifier - i.e. 'v1', 'v2', 'v2_1'",
         default=VERSION_DEFAULT,
     )
     flag_parser.add_argument(
